@@ -58,7 +58,7 @@ staging = []
 middleware = []
 extensions = []
 permissions = []
-on_startup = []
+on_startup = ["fastberry.extras.redirect_root"] # "fastberry.extras.graphql_info"
 on_shutdown = []
 """.strip()
             )
