@@ -11,7 +11,4 @@ import typing
 
 import fastberry as fb
 
-# Model
-model = fb.Model()
-
 # Create your <types> here.
